# Environments

This section provides an overview of the environments currently available in the Space Robotics Bench.

Before using these environments:

1. [Ensure you meet the system requirements](../../getting_started/requirements.md)
1. [Install the benchmark](../../getting_started/installation/index.html)
1. [Learn the basic usage](../../getting_started/usage.md)

Environments are separated into two categories:

- **Tasks** that come with an objective for an agent to complete. Therefore, each environment instance provides a reward signal that guides the agent towards completing the goal.
- **Demos** that provide a sandbox of the included capabilities without any specific objective. These environments can serve in the initial task design while designing a new scenario or defining the action and observation spaces.

The environments are grouped based on the robot type:

- [Mobile Robot Environments](./mobile.md)
- [Robotic Manipulation Environments](./manipulation.md)
